@@ -343,7 +343,7 @@ import os
 # basepath与惠楚确认
 basepath = os.path.expanduser('~/share/bby/')
 
-# 以下2选1, 请阅读波波鱼对接文档
+# 以下2选1, 请阅读博小鱼对接文档
 #os.chdir(basepath)
 #filepath = os.path.join(basepath, 'test.txt')`);
 };
@@ -390,7 +390,7 @@ const syncLesson = function () {
   })
     .then((response) => {
       if (response.ok) {
-        alert('同步成功，请刷新波波鱼步骤页后查看，中途请不要运行代码');
+        alert('同步成功，请刷新博小鱼步骤页后查看，中途请不要运行代码');
       } else {
         response.json().then((res) => {
           const reason = res.message || res.error || '原因未知';
