@@ -19,7 +19,7 @@ import '../css/extension.css';
 import { IJupyterCellMetadata } from '@boyuai/jupyter-helper/lib/types';
 
 /**
- * 注册波波鱼面板
+ * 注册博小鱼面板
  */
 export const registerBxyPanel = () => {
   bxy.init();
@@ -107,7 +107,7 @@ const bxy: {
       '<div id="bxy-setup-button" style=' +
       buttonStyleHtml +
       ' class="btn-group"><button class="btn btn-default" title="' +
-      '波波鱼面板开关' +
+      '博小鱼面板开关' +
       '">';
 
     if (!notebook.metadata.bxyId) {
@@ -320,7 +320,7 @@ const bxy: {
         }
       });
 
-    const logoText = '波波鱼控制面板';
+    const logoText = '博小鱼控制面板';
     bxy.setupOneControlPanel(
       'bxy-control-panel-title',
       '<div>' +
@@ -557,7 +557,7 @@ const bxy: {
         height: 12,
       },
       metaTag: 'bxy-id|' + cell.metadata.bxyCellId,
-      title: 'Cell 含有波波鱼特殊配置',
+      title: 'Cell 含有博小鱼特殊配置',
     });
     $(markerIcon).appendTo(element);
     const markerIcons = element.find('.bxy-right-side-marker');
